@@ -9,6 +9,7 @@ import logging
 from copy import deepcopy
 from email.utils import formatdate
 from pathlib import Path
+from re import compile
 
 # 3rd party
 from jinja2 import Environment, FileSystemLoader, select_autoescape
@@ -17,7 +18,6 @@ from mkdocs.plugins import BasePlugin
 from mkdocs.structure.pages import Page
 from mkdocs.utils import get_build_timestamp
 
-
 # package modules
 from .__about__ import __title__, __uri__, __version__
 from .customtypes import PageInformation
@@ -41,6 +41,8 @@ logger = logging.getLogger("mkdocs.mkdocs_rss_plugin")
 
 
 class GitRssPlugin(BasePlugin):
+    """Main class for MkDocs plugin."""
+
     config_scheme = (
         ("abstract_chars_count", config_options.Type(int, default=160)),
         ("category", config_options.Type(str, default=None)),
@@ -49,10 +51,12 @@ class GitRssPlugin(BasePlugin):
         ("image", config_options.Type(str, default=None)),
         ("length", config_options.Type(int, default=20)),
         ("pretty_print", config_options.Type(bool, default=False)),
-        ("match_path", config_options.Type(str, default=None)),
+        ("match_path", config_options.Type(str, default=".*")),
+        ("url_parameters", config_options.Type(dict, default=None)),
     )
 
     def __init__(self):
+        """Instanciation."""
         # tooling
         self.util = Util()
         # dates source
@@ -65,18 +69,18 @@ class GitRssPlugin(BasePlugin):
         self.feed_updated = dict
 
     def on_config(self, config: config_options.Config) -> dict:
-        """
-
-        The config event is the first event called on build and
+        """The config event is the first event called on build and
         is run immediately after the user configuration is loaded and validated.
         Any alterations to the config should be made here.
         https://www.mkdocs.org/user-guide/plugins/#on_config
 
-        Args:
-            config (dict): global configuration object
+        :param config: global configuration object
+        :type config: config_options.Config
 
-        Returns:
-            dict: global configuration object
+        :raises FileExistsError: if the template for the RSS feed is not found
+
+        :return: plugin configuration object
+        :rtype: dict
         """
         # check template dirs
         if not Path(DEFAULT_TEMPLATE_FILENAME).is_file():
@@ -105,6 +109,9 @@ class GitRssPlugin(BasePlugin):
         if self.config.get("image"):
             base_feed["logo_url"] = self.config.get("image")
 
+        # pattern to match pages included in output
+        self.match_path_pattern = compile(self.config.get("match_path"))
+
         # date handling
         if self.config.get("date_from_meta") is not None:
             self.src_date_created = self.config.get("date_from_meta").get(
@@ -157,15 +164,22 @@ class GitRssPlugin(BasePlugin):
 
         https://www.mkdocs.org/user-guide/plugins/#on_page_markdown
 
-        Args:
-            markdown (str): Markdown source text of page as string
-            page: mkdocs.nav.Page instance
-            config: global configuration object
-            site_navigation: global navigation object
+        :param markdown: Markdown source text of page as strin
+        :type markdown: str
+        :param page: mkdocs.nav.Page instance
+        :type page: Page
+        :param config: global configuration object
+        :type config: config_options.Config
+        :param files: global navigation object
+        :type files: [type]
 
-        Returns:
-            str: Markdown source text of page as string
+        :return: Markdown source text of page as strin
+        :rtype: str
         """
+        # skip pages that don't match the config var match_path
+        if not self.match_path_pattern.match(page.file.src_path):
+            return
+
         # retrieve dates from git log
         page_dates = self.util.get_file_dates(
             in_page=page,
@@ -174,6 +188,16 @@ class GitRssPlugin(BasePlugin):
             meta_datetime_format=self.meta_datetime_format,
         )
 
+        # handle custom URL parameters
+        if self.config.get("url_parameters"):
+            page_url_full = self.util.build_url(
+                base_url=page.canonical_url,
+                path="",
+                args_dict=self.config.get("url_parameters"),
+            )
+        else:
+            page_url_full = page.canonical_url
+
         # append to list to be filtered later
         self.pages_to_filter.append(
             PageInformation(
@@ -185,11 +209,11 @@ class GitRssPlugin(BasePlugin):
                 description=self.util.get_description_or_abstract(
                     in_page=page, chars_count=self.config.get("abstract_chars_count")
                 ),
+                guid=page.canonical_url,
                 image=self.util.get_image(
                     in_page=page, base_url=config.get("site_url", __uri__)
                 ),
-                url_full=page.canonical_url,
-                src_path=page.file.src_path,
+                url_full=page_url_full,
             )
         )
 
@@ -198,11 +222,10 @@ class GitRssPlugin(BasePlugin):
         Use this event to call post-build scripts. \
         See: <https://www.mkdocs.org/user-guide/plugins/#on_post_build>
 
-        Args:
-            config (dict): global configuration object
-
-        Returns:
-            dict: global configuration object
+        :param config: global configuration object
+        :type config: config_options.Config
+        :return: global configuration object
+        :rtype: dict
         """
         # pretty print or not
         pretty_print = self.config.get("pretty_print", False)
@@ -217,7 +240,6 @@ class GitRssPlugin(BasePlugin):
                 pages=self.pages_to_filter,
                 attribute="created",
                 length=self.config.get("length", 20),
-                match_path=self.config.get("match_path"),
             )
         )
 
@@ -227,7 +249,6 @@ class GitRssPlugin(BasePlugin):
                 pages=self.pages_to_filter,
                 attribute="updated",
                 length=self.config.get("length", 20),
-                match_path=self.config.get("match_path"),
             )
         )
 
