@@ -6,7 +6,6 @@
 
 # standard library
 import logging
-import re
 import ssl
 from datetime import date, datetime
 from email.utils import formatdate
@@ -194,11 +193,11 @@ class Util:
         """Returns authors from page meta. It handles 'author' and 'authors' for keys, \
         str and iterable as values types.
 
-        Args:
-            in_page (Page): page to look at
+        :param in_page: page to look into
+        :type in_page: Page
 
-        Returns:
-            Tuple[str]: tuple of authors names
+        :return: tuple of authors names
+        :rtype: Tuple[str] or None
         """
         # identify the key
         if "author" in in_page.meta:
@@ -328,7 +327,7 @@ class Util:
         # return final tuple
         return (img_url, mime_type, img_length)
 
-    def get_local_image_length(self, page_path: str, path_to_append: str) -> str:
+    def get_local_image_length(self, page_path: str, path_to_append: str) -> int:
         """Build URL using base URL, cumulating existing and passed path, \
         then adding URL arguments.
 
@@ -338,7 +337,7 @@ class Util:
         :type path: str
 
         :return: complete and valid path
-        :rtype: str
+        :rtype: int
         """
         image_path = Path(page_path).parent / Path(path_to_append)
         if not image_path.is_file():
@@ -367,7 +366,7 @@ class Util:
         :param ssl_context: SSL context, defaults to None
         :type ssl_context: ssl.SSLContext, optional
 
-        :return: image length
+        :return: image length as str or None
         :rtype: int
         """
         # prepare request
@@ -403,9 +402,9 @@ class Util:
                         err,
                     )
                 )
-                img_length = None
+                return None
 
-        return img_length
+        return int(img_length)
 
     @staticmethod
     def get_site_url(mkdocs_config: Config) -> str or None:
@@ -424,7 +423,7 @@ class Util:
 
         # cases
         if defined_site_url is None or not len(defined_site_url):
-            # in cas of mkdocs's behavior change
+            # in case of mkdocs's behavior change
             site_url = None
         else:
             site_url = defined_site_url
@@ -458,7 +457,7 @@ class Util:
             return None
 
     @staticmethod
-    def filter_pages(pages: list, attribute: str, length: int, match_path: str) -> list:
+    def filter_pages(pages: list, attribute: str, length: int) -> list:
         """Filter and return pages into a friendly RSS structure.
 
         :param pages: pages to filter
@@ -472,20 +471,18 @@ class Util:
         :rtype: list
         """
         filtered_pages = []
-        path_pattern = re.compile(match_path) if match_path else None
         for page in sorted(
             pages, key=lambda page: getattr(page, attribute), reverse=True
         )[:length]:
-            if path_pattern and not path_pattern.match(page.src_path):
-                continue
             filtered_pages.append(
                 {
                     "authors": page.authors,
                     "description": page.description,
+                    "guid": page.guid,
+                    "image": page.image,
                     "link": page.url_full,
                     "pubDate": formatdate(getattr(page, attribute)),
                     "title": page.title,
-                    "image": page.image,
                 }
             )
 
